@@ -5,16 +5,18 @@
 ##'     estimates and iterations of the estimates. If
 ##'     \code{return="pars"} (default) the final estimates are
 ##'     returned in addition to what other parameter-level information
-##'     is found. If \code{return="iterations"}, the iterations are
-##'     returned. If \code{return="both"}, both er returned, though in
-##'     separate data.frames compiled in a list.
+##'     is found, like FIX, sd etc. as columns. If
+##'     \code{return="iterations"}, the iterations are returned. If
+##'     \code{return="both"}, both er returned, though in separate
+##'     data.frames compiled in a list.
 ##' @param as.fun The default is to return data as a data.frame. Pass
 ##'     a function (say tibble::as_tibble) in as.fun to convert to
 ##'     something else. If data.tables are wanted, use
 ##'     as.fun="data.table". The default can be configured using
 ##'     NMdataConf.
-##' @param tableno In case the ext file contains multiple tables, this argument controls which one to choose. The options are
-##' \itemize{
+##' @param tableno In case the ext file contains multiple tables, this
+##'     argument controls which one to choose. The options are
+##'     \itemize{
 ##' 
 ##' \item "max" (default) Pick the table with the highest table
 ##' number. This typically means the results from the last
@@ -35,12 +37,42 @@
 ##'     can be the path to an input or output control stream, and
 ##'     `NMreadExt` will still read the `.ext` file.
 ##' @param file.ext Deprecated. Please use \code{file} instead.
-##' @return A list with a final parameter table and a table of the
-##'     iterations
+##' @details The parameter table returned if \code{return="pars"} or \code{return="all"} will contain columns based on the Nonmem 7.5 manual. It defines codes for different parameter-level values. They are:
+##'
+##' -1e+09: se
+##' -1000000002: eigCor
+##' -1000000003: cond
+##' -1000000004: stdDevCor
+##' -1000000005: seStdDevCor
+##' -1000000006: FIX
+##' -1000000007: termStat
+##' -1000000008: partLik
+##'
+##' The parameter name is in the \code{parameter} column. The
+##' "parameter type", like "THETA", "OMEGA", "SIGMA" are available in
+##' the \code{par.type} column. Counters are available in \code{i} and
+##' \code{j} columns. \code{j} will be \code{NA} for
+##' \code{par.type=="THETA"}
+##'
+##' The objective function value is included as a parameter.
+##'
+##' Notice that in case multiple tables are available in the `ext`
+##' file, the column names are taken from the first table. E.g., in
+##' case of SAEM/IMP estimation, the objective function values will be
+##' in the `SAEMOBJ` column, even for the IMP step. This may change in
+##' the future.
+##' 
+##' @return If \code{return="all"}, a list with a final parameter
+##'     table and a table of the iterations. If \code{return="pars"},
+##'     only the parameter table, and if \code{return="iterations"}
+##'     only the iterations table. If you need both, it may be more
+##'     efficient to only read the file once and use
+##'     \code{return="all"}. Often, only one of the two are needed,
+##'     and it more convenient to just extract one.
 ##' @import data.table
 ##' @export
 
-NMreadExt <- function(file,return="pars",as.fun,modelname,col.model,auto.ext,tableno="max",file.ext){
+NMreadExt <- function(file,return,as.fun,modelname,col.model,auto.ext,tableno="max",file.ext){
     
 #### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
 
@@ -67,15 +99,16 @@ NMreadExt <- function(file,return="pars",as.fun,modelname,col.model,auto.ext,tab
 
     if(is.null(tableno)) tableno <- "max"
 
-    if(! (is.character(tableno)&&tableno%in%c("min","max","all") ) ||
-       (is.numeric(tableno) && tableno>0 && tableno%%1==0) ){
+    if( (is.character(tableno)&& !tableno%in%c("min","max","all") ) ||
+        (is.numeric(tableno) && (tableno<=0 || tableno%%1!=0) )){
         stop("tableno must be either one of the character strings min, max, all or an integer greater than zero.")
     }
     
     args <- getArgs()
     if(missing(file.ext)) file.ext <- NULL
     file <- deprecatedArg("file.ext","file",args=args)
-    
+
+    if(missing(return)||is.null(return)) return <- "pars"
     allowed.return <- c("pars","iterations","all")
     if(!return %in% allowed.return){
         stop("Argument return has to be one of: ", paste(allowed.return,collapse =", "))
@@ -144,7 +177,8 @@ NMreadExt <- function(file,return="pars",as.fun,modelname,col.model,auto.ext,tab
     res.NMdat <- mergeCheck(res.NMdat,dt.codes,by=cc(ITERATION),all.x=T,quiet=TRUE)
     ## res.NMdat
 
-    pars <- res.NMdat[variable%in%dt.codes$variable,setdiff(colnames(res.NMdat),"OBJ"),with=FALSE]
+    ## pars <- res.NMdat[variable%in%dt.codes$variable,setdiff(colnames(res.NMdat),"OBJ"),with=FALSE]
+    pars <- res.NMdat[variable%in%dt.codes$variable]
     pars <- addTableStep(pars,keep.table.name=FALSE)
     if(nrow(pars)){
         pars <- melt(pars,id.vars=cc(model,TABLENO,NMREP,table.step,ITERATION,variable),variable.name="parameter")
