@@ -39,10 +39,12 @@
 ##' ## occasion level
 ##' findCovs(findVars(dt1,"ID"),c("ID","OCC"))
 ##' ## Based on a "real data example"
+##' \dontrun{
 ##' dat <- NMscanData(system.file("examples/nonmem/xgxr001.lst", package = "NMdata"))
 ##' findCovs(dat,by="ID")
 ##' ### Without an ID column we get non-varying columns
 ##' findCovs(dat)
+##' }
 ##' @export
 
 
@@ -51,11 +53,8 @@ findCovs <- function(data,by=NULL,cols.id,as.fun=NULL){
 
     
     ## check arguments
-    if(!missing(cols.id) && !is.null(by)) stop("\"cols.id\" is a deprecated name for the \"by\" argument. Just use \"by\"")
-    if(!missing(cols.id)) {
-        warning("\"cols.id\" argument deprecated. Use \"by\" instead.")
-        by <- cols.id
-    }
+    args <- getArgs()
+    by <- deprecatedArg("cols.id","by",args=args)
 
     if(!is.data.frame(data)){
         stop("data must be a data.frame (or data.table)")
